from docutils import nodes
import jinja2
from docutils.parsers.rst.directives import unchanged
from docutils.parsers.rst import Directive

EDITOR_TEMPLATE = jinja2.Template(
    u"""
  <div class="ace-editor"
       data-language="{{language}}"
       data-id="{{id}}"
       data-height="{{height}}"
       data-tr-endpoint="{{ tracking_endpoint }}">{{code}}</div>
"""
)


# placeholder node for document graph
class editor_node(nodes.General, nodes.Element):
    pass


class CodeEditorDirective(Directive):
    has_content = True
    required_arguments = 0

    option_spec = {
        "code": unchanged,
        "id": unchanged,
        "language": unchanged,
        "height": unchanged,
        "tracking_endpoint": unchanged,
    }

    # this will execute when your directive is encountered
    # it will insert a ace_node into the document that will
    # get visisted during the build phase
    def run(self):
        env = self.state.document.settings.env
        app = env.app

        node = editor_node()
        node["code"] = u"\n".join(self.content).strip()
        node["id"] = self.options["id"]
        node["language"] = self.options["language"]
        node["height"] = self.options["height"]
        node["tracking_endpoint"] = self.options["tracking_endpoint"]
        return [node]


def html_visit_ace_node(self, node):
    html = EDITOR_TEMPLATE.render(
        code=node["code"],
        id=node["id"],
        language=node["language"],
        height=node["height"],
        tracking_endpoint=node["tracking_endpoint"],
    )
    self.body.append(html)
    raise nodes.SkipNode


def setup(app):
    app.add_node(editor_node, html=(html_visit_ace_node, None))
    app.add_directive("code-editor", CodeEditorDirective)
