from __future__ import absolute_import
from docutils import nodes
import jinja2
from docutils.parsers.rst.directives import unchanged
from docutils.parsers.rst import Directive

APIDOC_TEMPLATE = jinja2.Template(
    u"""

<body>
  <redoc spec-url="{{ path }}"></redoc>
  <script src="https://storage.googleapis.com/docs-theme/redoc.standalone.js?v=1"></script>
</body>

"""
)

# placeholder node for document graph
class apidoc_node(nodes.General, nodes.Element):
    pass


class ApidocDirective(Directive):
    required_arguments = 0

    option_spec = {"path": unchanged}

    # this will execute when your directive is encountered
    # it will insert a apidoc_node into the document that will
    # get visisted during the build phase
    def run(self):
        env = self.state.document.settings.env
        app = env.app
        node = apidoc_node()
        node["path"] = self.options["path"]
        return [node]


# build phase visitor emits HTML to append to output
def html_visit_apidoc_node(self, node):
    html = APIDOC_TEMPLATE.render(path=node["path"])
    self.body.append(html)
    raise nodes.SkipNode


# if you want to be pedantic, define text, latex, manpage visitors too..


def setup(app):
    app.add_node(apidoc_node, html=(html_visit_apidoc_node, None))
    app.add_directive("apidoc", ApidocDirective)
