from __future__ import absolute_import
from docutils import nodes
import jinja2
from docutils.parsers.rst.directives import unchanged
from docutils.parsers.rst import Directive
import ruamel.yaml

CONVERSATIONS_TEMPLATE = jinja2.Template(
    u"""

<div class="dialogue-conversations">
  <div class="columns smtb tinycard">
    {% for example in examples %}
      <div class="column">
          <div class="dialogue-example">
            {% for message in example %}
              {% if message.startswith('( ')  %}
                <div class="chat-bubble bot">
                  <p>{{ message | replace('( ', '') }}</p>
                </div>
              {% elif message.startswith('^ ')  %}
                <div class="chat-bubble quickreply">
                  <p>{{ message | replace('^ ', '') }}</p>
                </div>
              {% else %}
                <div class="chat-bubble user">
                  <p>{{ message }}</p>
                </div>
              {% endif %}
            {% endfor %}
          </div>
      </div>
    {% endfor %}
  </div>
</div>
"""
)

# placeholder node for document graph
class conversations_node(nodes.General, nodes.Element):
    pass


def read_yaml(string):
    yaml_parser = ruamel.yaml.YAML(typ="safe")
    yaml_parser.version = "1.1"
    yaml_parser.unicode_supplementary = True

    return yaml_parser.load(string)


class ConversationsDirective(Directive):
    required_arguments = 0

    has_content = True

    # this will execute when your directive is encountered
    # it will insert a conversations_node into the document that will
    # get visisted during the build phase
    def run(self):
        env = self.state.document.settings.env
        app = env.app
        node = conversations_node()
        node["content"] = "\n".join(self.content)
        return [node]


# build phase visitor emits HTML to append to output
def html_visit_conversations_node(self, node):
    data = read_yaml(node["content"])
    html = CONVERSATIONS_TEMPLATE.render(examples=data["examples"])
    self.body.append(html)
    raise nodes.SkipNode


# if you want to be pedantic, define text, latex, manpage visitors too..


def setup(app):
    app.add_node(conversations_node, html=(html_visit_conversations_node, None))
    app.add_directive("conversations", ConversationsDirective)
