from docutils import nodes
import jinja2
from docutils.parsers.rst import Directive


BUTTON_TEMPLATE = jinja2.Template(
    u"""
    <button 
        disabled
        class="button download__button"
    >
        Download project
    </button>
"""
)

# placeholder node for document graph
class download_button_node(nodes.General, nodes.Element):
    pass


class DownloadButtonDirective(Directive):
    required_arguments = 0

    option_spec = {}

    # this will execute when your directive is encountered
    # it will insert a button_node into the document that will
    # get visited during the build phase
    def run(self):
        env = self.state.document.settings.env
        app = env.app

        node = download_button_node()
        return [node]


def html_download_button_node(self, node):
    html = BUTTON_TEMPLATE.render()
    self.body.append(html)
    raise nodes.SkipNode


def setup(app):
    app.add_node(download_button_node, html=(html_download_button_node, None))
    app.add_directive("download-button", DownloadButtonDirective)
