from __future__ import absolute_import
from docutils import nodes
import jinja2
from docutils.parsers.rst.directives import unchanged
from docutils.parsers.rst import Directive

EDIT_LINK_TEMPLATE = jinja2.Template(
    u"""
  <div class="edit-link">
    <a class="reference external" href="{{ url }}" target="_blank"><i class="fab fa-github" style="font-size: 85%; padding-right: 4px;"></i>{{ text }}</a>
  </div>
"""
)


# placeholder node for document graph
class edit_node(nodes.General, nodes.Element):
    pass


class EditLinkDirective(Directive):
    required_arguments = 0

    option_spec = {"url": unchanged, "text": unchanged}

    def run(self):
        env = self.state.document.settings.env
        app = env.app

        node = edit_node()
        default_link = "https://github.com/RasaHQ/rasa/edit/master/docs/{}.rst".format(
            env.docname
        )
        node["url"] = self.options.get("url", default_link)
        node["text"] = self.options.get("text", "SUGGEST EDITS")

        return [node]


# build phase visitor emits HTML to append to output
def html_visit_edit_node(self, node):
    html = EDIT_LINK_TEMPLATE.render(url=node["url"], text=node["text"])
    self.body.append(html)
    raise nodes.SkipNode


def setup(app):
    app.add_node(edit_node, html=(html_visit_edit_node, None))
    app.add_directive("edit-link", EditLinkDirective)
